@@ -22,11 +22,10 @@ leafletTerminatorDependencies <- function() {
 #' @param group the name of the group this layer belongs to.
 #' @param options the path options for the daynight layer
 #' @examples
-#' library(leaflet)
-#'
 #' leaf <- leaflet() %>%
 #'   addTiles() %>%
 #'   addTerminator()
+#' leaf
 #'
 #' @export
 addTerminator <- function(
@@ -34,14 +33,14 @@ addTerminator <- function(
   resolution = 2,
   time = NULL,
   layerId = NULL,
-  group=NULL,
-  options = pathOptions(pointerEvents="none", clickable=FALSE) # Default unclickable
+  group = NULL,
+  options = pathOptions(pointerEvents = "none", clickable = FALSE) # Default unclickable
 ) {
   map$dependencies <- c(map$dependencies, leafletTerminatorDependencies())
   invokeMethod(
     map,
     getMapData(map),
-    'addTerminator',
+    "addTerminator",
     resolution,
     time,
     layerId,
