@@ -3,11 +3,11 @@ library(R6)
 
 # This class is copied from Shiny
 Map <- R6Class(
-  'Map',
+  "Map",
   portable = FALSE,
   public = list(
     initialize = function() {
-      private$env <- new.env(parent=emptyenv())
+      private$env <- new.env(parent = emptyenv())
     },
     get = function(key) {
       env[[key]]
@@ -35,21 +35,21 @@ Map <- R6Class(
         return(NULL)
 
       result <- env[[key]]
-      rm(list=key, envir=env, inherits=FALSE)
+      rm(list = key, envir = env, inherits = FALSE)
       result
     },
     containsKey = function(key) {
-      exists(key, envir=env, inherits=FALSE)
+      exists(key, envir = env, inherits = FALSE)
     },
     keys = function() {
       # Sadly, this is much faster than ls(), because it doesn't sort the keys.
-      names(as.list(env, all.names=TRUE))
+      names(as.list(env, all.names = TRUE))
     },
     values = function() {
-      as.list(env, all.names=TRUE)
+      as.list(env, all.names = TRUE)
     },
     clear = function() {
-      private$env <- new.env(parent=emptyenv())
+      private$env <- new.env(parent = emptyenv())
       invisible(NULL)
     },
     size = function() {
@@ -58,19 +58,19 @@ Map <- R6Class(
   ),
 
   private = list(
-    env = 'environment'
+    env = "environment"
   )
 )
 
 
 # This class is copied from Shiny
 Callbacks <- R6Class(
-  'Callbacks',
+  "Callbacks",
   portable = FALSE,
   class = FALSE,
   public = list(
     .nextId = integer(0),
-    .callbacks = 'Map',
+    .callbacks = "Map",
 
     initialize = function() {
       .nextId <<- as.integer(.Machine$integer.max)
@@ -84,7 +84,7 @@ Callbacks <- R6Class(
         .callbacks$remove(id)
       })
     },
-    invoke = function(..., onError=NULL) {
+    invoke = function(..., onError = NULL) {
       # Ensure that calls are invoked in the order that they were registered
       keys <- as.character(sort(as.integer(.callbacks$keys()), decreasing = TRUE))
       callbacks <- .callbacks$mget(keys)
@@ -123,7 +123,9 @@ MockSession <- R6Class("MockSession",
       })
     },
     onSessionEnded = function(func) {
-      function() {}
+      function() {
+        # nothing
+      }
     },
     token = 0,
     .flush = function() {
@@ -142,7 +144,7 @@ local <- leaflet()
 mockSession <- MockSession$new()
 remote <- leafletProxy("map", mockSession)
 
-remote %>% addPolygons(lng=1:5, lat=1:5)
+remote %>% addPolygons(lng = 1:5, lat = 1:5)
 
 # Check that remote functions only get invoked after flush, by default
 assert(
@@ -150,8 +152,11 @@ assert(
   identical(mockSession$.calls, list())
 )
 mockSession$.flush()
-expected <- list(structure(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"addPolygons\",\"args\":[[[[{\"lng\":[1,2,3,4,5],\"lat\":[1,2,3,4,5]}]]],null,null,{\"lineCap\":null,\"lineJoin\":null,\"clickable\":true,\"pointerEvents\":null,\"className\":\"\",\"stroke\":true,\"color\":\"#03F\",\"weight\":5,\"opacity\":0.5,\"fill\":true,\"fillColor\":\"#03F\",\"fillOpacity\":0.2,\"dashArray\":null,\"smoothFactor\":1,\"noClip\":false},null,null,null,null,null]}]}", class = "json")), .Names = c("type",
-  "message")))
+# nolint start
+expected <- list(structure(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"addPolygons\",\"args\":[[[[{\"lng\":[1,2,3,4,5],\"lat\":[1,2,3,4,5]}]]],null,null,{\"interactive\":true,\"className\":\"\",\"stroke\":true,\"color\":\"#03F\",\"weight\":5,\"opacity\":0.5,\"fill\":true,\"fillColor\":\"#03F\",\"fillOpacity\":0.2,\"smoothFactor\":1,\"noClip\":false},null,null,null,{\"interactive\":false,\"permanent\":false,\"direction\":\"auto\",\"opacity\":1,\"offset\":[0,0],\"textsize\":\"10px\",\"textOnly\":false,\"className\":\"\",\"sticky\":true},null]}]}", class = "json")), .Names = c("type",
+"message")))
+# nolint end
+
 dput(mockSession$.calls)
 assert(identical(mockSession$.calls, expected))
 
@@ -161,12 +166,13 @@ mockSession$.calls <- list()
 
 # Create another remote map which doesn't wait until flush
 remote2 <- leafletProxy("map", mockSession,
-  data.frame(lat=10:1, lng=10:1),
+  data.frame(lat = 10:1, lng = 10:1),
   deferUntilFlush = FALSE
 )
 # Check that addMarkers() takes effect immediately, no flush required
 remote2 %>% addMarkers()
-expected2 <- list(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"addMarkers\",\"args\":[[10,9,8,7,6,5,4,3,2,1],[10,9,8,7,6,5,4,3,2,1],null,null,null,{\"clickable\":true,\"draggable\":false,\"keyboard\":true,\"title\":\"\",\"alt\":\"\",\"zIndexOffset\":0,\"opacity\":1,\"riseOnHover\":false,\"riseOffset\":250},null,null,null,null,null,null,null]}]}", class = "json")))
+expected2 <- list(structure(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"addMarkers\",\"args\":[[10,9,8,7,6,5,4,3,2,1],[10,9,8,7,6,5,4,3,2,1],null,null,null,{\"interactive\":true,\"draggable\":false,\"keyboard\":true,\"title\":\"\",\"alt\":\"\",\"zIndexOffset\":0,\"opacity\":1,\"riseOnHover\":false,\"riseOffset\":250},null,null,null,null,null,{\"interactive\":false,\"permanent\":false,\"direction\":\"auto\",\"opacity\":1,\"offset\":[0,0],\"textsize\":\"10px\",\"textOnly\":false,\"className\":\"\",\"sticky\":true},null]}]}", class = "json")), .Names = c("type",
+"message"))) # nolint
 # cat(deparse(mockSession$.calls), "\n")
 assert(identical(mockSession$.calls, expected2))
 # Flushing should do nothing
@@ -178,12 +184,16 @@ assert(identical(mockSession$.calls, expected2))
 mockSession$.calls <- list()
 
 remote3 <- leafletProxy("map", mockSession,
-  data.frame(lat=10:1, lng=10:1)
+  data.frame(lat = 10:1, lng = 10:1)
 )
 remote3 %>% clearShapes() %>% addMarkers()
 assert(identical(mockSession$.calls, list()))
 mockSession$.flush()
-expected3 <- list(structure(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"clearShapes\",\"args\":[]}]}", class = "json")), .Names = c("type", "message")), structure(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"addMarkers\",\"args\":[[10,9,8,7,6,5,4,3,2,1],[10,9,8,7,6,5,4,3,2,1],null,null,null,{\"clickable\":true,\"draggable\":false,\"keyboard\":true,\"title\":\"\",\"alt\":\"\",\"zIndexOffset\":0,\"opacity\":1,\"riseOnHover\":false,\"riseOffset\":250},null,null,null,null,null,null,null]}]}", class = "json")), .Names = c("type", "message")))
+# nolint start
+expected3 <- list(structure(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"clearShapes\",\"args\":[]}]}", class = "json")), .Names = c("type",
+"message")), structure(list(type = "leaflet-calls", message = structure("{\"id\":\"map\",\"calls\":[{\"dependencies\":[],\"method\":\"addMarkers\",\"args\":[[10,9,8,7,6,5,4,3,2,1],[10,9,8,7,6,5,4,3,2,1],null,null,null,{\"interactive\":true,\"draggable\":false,\"keyboard\":true,\"title\":\"\",\"alt\":\"\",\"zIndexOffset\":0,\"opacity\":1,\"riseOnHover\":false,\"riseOffset\":250},null,null,null,null,null,{\"interactive\":false,\"permanent\":false,\"direction\":\"auto\",\"opacity\":1,\"offset\":[0,0],\"textsize\":\"10px\",\"textOnly\":false,\"className\":\"\",\"sticky\":true},null]}]}", class = "json")), .Names = c("type",
+"message")))
+# nolint end
 
 # Check that multiple calls are invoked in order
 assert(identical(mockSession$.calls, expected3))
